@@ -1,9 +1,10 @@
 import inspect
 import warnings
-from typing import Callable, Dict, Mapping, Optional, Sequence, Union
+from typing import Any, Callable, Dict, Optional, Tuple, Union
 
 import smartparams.utils.string as strutil
 import smartparams.utils.typing as typeutil
+from smartparams.utils.enums import Option
 
 
 class SmartRegister:
@@ -19,15 +20,16 @@ class SmartRegister:
     def origins(self) -> Dict[str, str]:
         return self._origins.copy()
 
+    def reset(self) -> None:
+        """Removes all registered classes and aliases."""
+        self._aliases.clear()
+        self._origins.clear()
+
     def __call__(
         self,
-        classes: Union[
-            Sequence[Union[str, Callable]],
-            Mapping[str, str],
-            Mapping[Callable, str],
-            Mapping[Union[str, Callable], str],
-        ],
+        *classes: Union[str, Callable, Tuple[Union[str, Callable], str]],
         prefix: str = '',
+        option: Optional[str] = None,
         force: Optional[bool] = None,
     ) -> None:
         """Registers given classes with aliases.
@@ -41,50 +43,25 @@ class SmartRegister:
             Use mapping to register a class with a custom alias (class -> alias).
 
         """
-        if isinstance(classes, Sequence):
-            self._register_classes(
-                classes=classes,
-                prefix=prefix,
-                force=force,
-            )
-        elif isinstance(classes, Mapping):
-            self._register_aliases(
-                aliases=classes,
-                prefix=prefix,
-                force=force,
-            )
-        else:
-            raise TypeError(f"Register classes type '{type(classes)}' is not supported.")
+        for origin, alias in dict(self._create_alias(c) for c in classes).items():
+            if isinstance(origin, str):
+                origin = origin
+            elif callable(origin):
+                origin = inspect.formatannotation(origin)
+                if option:
+                    option = option.upper()
+                    if option not in Option.keys():
+                        raise ValueError(
+                            f"Option {option} is not supported. "
+                            f"Available: {', '.join(Option.keys())}."
+                        )
+                    origin = strutil.join_objects(origin, Option[option])
+            else:
+                raise TypeError(f"Origin have to be a string or callable instead of {type(alias)}.")
 
-    def reset(self) -> None:
-        """Removes all registered classes and aliases."""
-        self._aliases.clear()
-        self._origins.clear()
+            if not isinstance(alias, str):
+                raise TypeError(f"Alias have to be a string instead of {type(alias)}.")
 
-    def _register_classes(
-        self,
-        classes: Sequence[Union[str, Callable]],
-        prefix: str = '',
-        force: Optional[bool] = None,
-    ) -> None:
-        self._register_aliases(
-            aliases={c: c if isinstance(c, str) else typeutil.get_name(c) for c in classes},
-            prefix=prefix,
-            force=force,
-        )
-
-    def _register_aliases(
-        self,
-        aliases: Union[
-            Mapping[str, str],
-            Mapping[Callable, str],
-            Mapping[Union[str, Callable], str],
-        ],
-        prefix: str = '',
-        force: Optional[bool] = None,
-    ) -> None:
-        for origin, alias in aliases.items():
-            origin = origin if isinstance(origin, str) else inspect.formatannotation(origin)
             alias = strutil.join_keys(prefix, alias)
 
             if origin in self._aliases:
@@ -105,3 +82,13 @@ class SmartRegister:
 
             self._aliases[origin] = alias
             self._origins[alias] = origin
+
+    @staticmethod
+    def _create_alias(obj: Any) -> Tuple[Union[str, Callable], str]:
+        if isinstance(obj, str):
+            return obj, obj
+        if isinstance(obj, tuple):
+            if len(obj) != 2:
+                raise ValueError("A tuple must consist of 2 elements (class, alias).")
+            return obj  # type: ignore
+        return obj, typeutil.get_name(obj)
