@@ -29,13 +29,17 @@ from smartparams.exceptions import (
 _T = TypeVar('_T')
 
 
+def parse_class_name(name: str) -> Tuple[str, str]:
+    name, _, option = name.partition(strutil.OBJECT_SEPARATOR)
+    return name, option
+
+
 def parse_object(
     dictionary: Dict[str, Any],
     keyword: str,
 ) -> Tuple[Dict[str, Any], str, Optional[str]]:
     kwargs = dictionary.copy()
-    name = kwargs.pop(keyword)
-    name, _, option = name.partition(strutil.OBJECT_SEPARATOR)
+    name, option = parse_class_name(kwargs.pop(keyword))
     return kwargs, name, option
 
 
